## nobug
[![PyPI version](https://img.shields.io/pypi/v/nobug.svg)](https://pypi.python.org/pypi/nobug/)

没有bug
没有bug
没有bug

佛祖、Jesus、神兽保佑代码无bug

## introduction

[gist](https://gist.github.com/edokeh/7580064) 上看到了好多这样有趣的图，但是pypi里面没有找到可以直接用的包，于是决定皮一下



于是有了这个


## install
```
$ pip3 install nobug
```

## usage

选一个吧



![](http://oqyjccf1n.bkt.clouddn.com/20180403-183332.png)




![](http://oqyjccf1n.bkt.clouddn.com/20180403-183451.png)

![](http://oqyjccf1n.bkt.clouddn.com/20180403-183526.png)

![](http://oqyjccf1n.bkt.clouddn.com/20180403-183603.png)

![](http://oqyjccf1n.bkt.clouddn.com/20180403-183655.png)

当然了，代码写完了最后需要庆祝一下

![](http://oqyjccf1n.bkt.clouddn.com/20180403-183732.png)

## 跋

皮这一下很快乐

## refer

- [gist](https://gist.github.com/edokeh/7580064)
